@@ -3,8 +3,9 @@ Main interface for workdocs service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.workdocs import (
+    from mypy_boto3_workdocs import (
         Client,
         DescribeActivitiesPaginator,
         DescribeCommentsPaginator,
@@ -16,7 +17,7 @@ Usage::
         DescribeRootFoldersPaginator,
         DescribeUsersPaginator,
         WorkDocsClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -32,6 +33,7 @@ Usage::
     describe_resource_permissions_paginator: DescribeResourcePermissionsPaginator = client.get_paginator("describe_resource_permissions")
     describe_root_folders_paginator: DescribeRootFoldersPaginator = client.get_paginator("describe_root_folders")
     describe_users_paginator: DescribeUsersPaginator = client.get_paginator("describe_users")
+    ```
 """
 from mypy_boto3_workdocs.client import WorkDocsClient, WorkDocsClient as Client
 from mypy_boto3_workdocs.paginator import (
